@@ -5,6 +5,7 @@ import base64
 import logging
 import requests
 import jwcrypto.jwk as jwk
+from functools import wraps
 
 from django.contrib.auth.models import User
 from django.contrib import auth as django_auth
@@ -13,7 +14,6 @@ from django.conf import settings
 from django.shortcuts import redirect
 from django.contrib.auth import logout
 from django.core.exceptions import PermissionDenied
-from django.http import HttpResponseForbidden, HttpResponseServerError
 
 logger = logging.getLogger(__name__)
 
@@ -30,6 +30,7 @@ def jwt_and_manage(item):
 
     def real_decorator(function):
 
+        @wraps(function)
         def wrap(request, *args, **kwargs):
 
             # Validates the JWT and returns its payload if valid.
@@ -76,14 +77,14 @@ def jwt_and_manage(item):
                 logger.debug('Missing/invalid JWT, sending to login')
                 return logout_redirect(request)
 
-        wrap.__doc__ = function.__doc__
-        wrap.__name__ = function.__name__
         return wrap
 
     return real_decorator
 
 
 def public_user_auth_and_jwt(function):
+
+    @wraps(function)
     def wrap(request, *args, **kwargs):
         """
         Here we see if the user is logged in but let them stay on the page if they aren't.
@@ -103,8 +104,6 @@ def public_user_auth_and_jwt(function):
 
         return function(request, *args, **kwargs)
 
-    wrap.__doc__ = function.__doc__
-    wrap.__name__ = function.__name__
     return wrap
 
 
@@ -118,6 +117,7 @@ def user_auth_and_jwt(function):
     :param function: The protected method
     :return: decorator
     '''
+    @wraps(function)
     def wrap(request, *args, **kwargs):
 
         # Validates the JWT and returns its payload if valid.
@@ -141,8 +141,7 @@ def user_auth_and_jwt(function):
         # User doesn't pass muster, throw them to the login app.
         else:
             return logout_redirect(request)
-    wrap.__doc__ = function.__doc__
-    wrap.__name__ = function.__name__
+
     return wrap
 
 
@@ -154,6 +153,7 @@ def dbmi_jwt(function):
     :return:
     :rtype:
     '''
+    @wraps(function)
     def wrap(request, *args, **kwargs):
 
         # Validates the JWT and returns its payload if valid.
@@ -167,8 +167,6 @@ def dbmi_jwt(function):
             logger.debug('Missing/invalid JWT, sending to login')
             return logout_redirect(request)
 
-    wrap.__doc__ = function.__doc__
-    wrap.__name__ = function.__name__
     return wrap
 
 
@@ -521,13 +519,13 @@ def logout_redirect(request):
 
 class Auth0Authentication(object):
 
-    def authenticate(self, **token_dictionary):
-        logger.debug("Attempting to Authenticate User.")
+    def authenticate(self, request, **token_dictionary):
+        logger.debug("Authenticate User: {}/{}".format(token_dictionary.get('sub'), token_dictionary.get('email')))
 
         try:
             user = User.objects.get(username=token_dictionary["email"])
         except User.DoesNotExist:
-            logger.debug("User not found, creating.")
+            logger.debug("User not found, creating: {}".format(token_dictionary.get('email')))
 
             user = User(username=token_dictionary["email"], email=token_dictionary["email"])
             user.save()
